@@ -8,12 +8,13 @@ from django.utils.safestring import mark_safe
 
 
 class AceWidget(forms.Textarea):
-    def __init__(self, mode=None, theme=None, wordwrap=False, width="500px", height="300px", *args, **kwargs):
+    def __init__(self, mode=None, theme=None, wordwrap=False, width="500px", height="300px", showprintmargin=True, *args, **kwargs):
         self.mode = mode
         self.theme = theme
         self.wordwrap = wordwrap
         self.width = width
         self.height = height
+        self.showprintmargin = showprintmargin
         super(AceWidget, self).__init__(*args, **kwargs)
 
     @property
@@ -44,6 +45,7 @@ class AceWidget(forms.Textarea):
             ace_attrs["data-theme"] = self.theme
         if self.wordwrap:
             ace_attrs["data-wordwrap"] = "true"
+        ace_attrs["data-showprintmargin"] = "true" if self.showprintmargin else "false"
 
         textarea = super(AceWidget, self).render(name, value, attrs)
 
